@@ -18,7 +18,7 @@ test_that("repreated parsing solves wrong parent assignment", {
   file.copy(path_perm, dir)
 
   sys_call <- paste0(
-    "R -q -e \"styler::style_file(\\\"", path_temp, "\\\")\""
+    "R -q -e \"styler::cache_deactivate(); styler::style_file(\\\"", path_temp, "\\\")\""
   )
   calls_sys(sys_call, intern = FALSE, ignore.stdout = TRUE, ignore.stderr = TRUE)
   ref <- xfun::read_utf8(testthat_file("parsing", "repeated_parsing-out.R"))
