@@ -2,4 +2,6 @@ if (X) {
   return(TRUE)
 }
 
-if (X) return(FALSE)
+if (X) {
+  return(FALSE)
+}
